[cig-commits] r6717 - in short/3D/PyLith/trunk: . pylith/faults unittests/libtests/materials

brad at geodynamics.org brad at geodynamics.org
Fri Apr 27 13:48:56 PDT 2007


Author: brad
Date: 2007-04-27 13:48:55 -0700 (Fri, 27 Apr 2007)
New Revision: 6717

Modified:
   short/3D/PyLith/trunk/TODO
   short/3D/PyLith/trunk/pylith/faults/EqKinSrc.py
   short/3D/PyLith/trunk/pylith/faults/SlipTimeFn.py
   short/3D/PyLith/trunk/unittests/libtests/materials/TestMaterial.cc
Log:
Updated TODO. Fixed a few broken unit tests.

Modified: short/3D/PyLith/trunk/TODO
===================================================================
--- short/3D/PyLith/trunk/TODO	2007-04-27 20:32:24 UTC (rev 6716)
+++ short/3D/PyLith/trunk/TODO	2007-04-27 20:48:55 UTC (rev 6717)
@@ -31,14 +31,8 @@
    c. Start implementing integrator for faults
 
      i. Update Reference cell
-       (1) Compute basis and basisDeriv at vertices
-       (2) Add unit tests
+       (1) Get vertices from FIAT [requested Matt fix]
 
-     ii. Update Quadrature
-       (1) Add basis and basisDeriv at vertices to Quadrature
-       (2) Add computeGeometryQuad/computeGeometryVert to Quadrature
-       (3) Add unit tests
-
      iii. FaultCohesive
        (1) Unit tests
 

Modified: short/3D/PyLith/trunk/pylith/faults/EqKinSrc.py
===================================================================
--- short/3D/PyLith/trunk/pylith/faults/EqKinSrc.py	2007-04-27 20:32:24 UTC (rev 6716)
+++ short/3D/PyLith/trunk/pylith/faults/EqKinSrc.py	2007-04-27 20:48:55 UTC (rev 6717)
@@ -21,7 +21,7 @@
 ##
 ## Factory: eq_kinematic_src
 
-from Component import Component
+from pyre.components.Component import Component
 
 # EqKinSrc class
 class EqKinSrc(Component):

Modified: short/3D/PyLith/trunk/pylith/faults/SlipTimeFn.py
===================================================================
--- short/3D/PyLith/trunk/unittests/libtests/materials/TestMaterial.cc	2007-04-27 20:32:24 UTC (rev 6716)
+++ short/3D/PyLith/trunk/unittests/libtests/materials/TestMaterial.cc	2007-04-27 20:48:55 UTC (rev 6717)
@@ -127,12 +127,19 @@
   const int numCorners = 3;
   const int numQuadPts = 2;
   const int spaceDim = 1;
-  const double basis[] = { 0.455, 0.667, -0.122, -0.122, 0.667, 0.455 };
-  const double basisDeriv[] = { -1.077, 1.155, -0.077, 0.077, -1.155, 1.077 };
+  const double basisVert[] = { 0.455, 0.667, -0.122, 
+			       -0.122, 0.667, 0.455,
+			       -0.145, 0.6345, 0.653};
+  const double basisDerivVert[] = { -1.077, 1.155, -0.077,
+				    0.077, -1.155, 1.077,
+				    0.074, -1.355, 2.077};
+  const double basisQuad[] = { 0.455, 0.667, -0.122, -0.122, 0.667, 0.455 };
+  const double basisDerivQuad[] = { -1.077, 1.155, -0.077, 0.077, -1.155, 1.077 };
   const double quadPtsRef[] = { -0.577350269, 0.577350269 };
   const double quadWts[] = { 1.0, 1.0  };
-  quadrature.initialize(basis, basisDeriv, quadPtsRef, quadWts,
-	       cellDim, numCorners, numQuadPts, spaceDim);
+  quadrature.initialize(basisVert, basisDerivVert, basisQuad, basisDerivQuad, 
+			quadPtsRef, quadWts,
+			cellDim, numCorners, numQuadPts, spaceDim);
 
   spatialdata::spatialdb::SimpleDB db;
   spatialdata::spatialdb::SimpleIOAscii iohandler;



More information about the cig-commits mailing list
--- short/3D/PyLith/trunk/pylith/faults/SlipTimeFn.py	2007-04-27 20:32:24 UTC (rev 6716)
+++ short/3D/PyLith/trunk/pylith/faults/SlipTimeFn.py	2007-04-27 20:48:55 UTC (rev 6717)
@@ -29,13 +29,13 @@
 
   # INVENTORY //////////////////////////////////////////////////////////
 
-  class Inventory(SlipTimeFn.Inventory):
+  class Inventory(Component.Inventory):
     """
-    Python object for managing BruneSlipFn facilities and properties.
+    Python object for managing Component facilities and properties.
     """
     
     ## @class Inventory
     ## Python object for managing BruneSlipFn facilities and properties.
     ##
     ## \b Properties
     ## @li None
@@ -29,13 +29,13 @@
     
     ## @class Inventory
-    ## Python object for managing BruneSlipFn facilities and properties.
+    ## Python object for managing Component facilities and properties.
     ##
     ## \b Properties

Modified: short/3D/PyLith/trunk/unittests/libtests/materials/TestMaterial.cc
===================================================================